@@ -237,7 +237,7 @@ def handle_request_with_token(
             verify=False,
             options={'verify_signature': False}
         )
-        now = int(time.time())
+        now = int(time.time() + 10)
 
         if access_token.get('exp') and now >= access_token['exp']:
             refresh_token(config_data)
@@ -470,7 +470,7 @@ def echo_verbose_results(data, no_color):
         else:
             fg = 'red'
 
-        name = parse_test_name(test['name'])
+        name = parse_test_name(test['nodeid'])
         echo_style(
             '{} {}'.format(name, test['outcome'].upper()),
             no_color,
